@@ -377,6 +377,7 @@ class KerberosTestCase(unittest.TestCase):
 
 
     def test_handle_response_401(self):
+        # Get a 401 from server, authenticate, and get a 200 back.
         with patch.multiple('kerberos',
                             authGSSClientInit=clientInit_complete,
                             authGSSClientResponse=clientResponse,
@@ -402,10 +403,14 @@ class KerberosTestCase(unittest.TestCase):
             response.connection = connection
             response._content = ""
             response.raw = raw
+
             auth = requests_kerberos.HTTPKerberosAuth()
+            auth.handle_other = Mock(return_value=response_ok)
+
             r = auth.handle_response(response)
 
             self.assertTrue(response in r.history)
+            auth.handle_other.assert_called_once_with(response_ok)
             self.assertEqual(r, response_ok)
             self.assertEqual(request.headers['Authorization'], 'Negotiate GSSRESPONSE')
             connection.send.assert_called_with(request)
@@ -413,6 +418,51 @@ class KerberosTestCase(unittest.TestCase):
             clientInit_complete.assert_called_with("HTTP@www.example.org")
             clientStep_continue.assert_called_with("CTX", "token")
             clientResponse.assert_called_with("CTX")
+            
+    def test_handle_response_401_rejected(self):
+        # Get a 401 from server, authenticate, and get another 401 back.
+        # Ensure there is no infinite recursion.
+        with patch.multiple('kerberos',
+                            authGSSClientInit=clientInit_complete,
+                            authGSSClientResponse=clientResponse,
+                            authGSSClientStep=clientStep_continue):
+
+            connection = Mock()
+
+            def connection_send(self, *args, **kwargs):
+                reject = requests.Response()
+                reject.url = "http://www.example.org/"
+                reject.status_code = 401
+                reject.connection = connection
+                return reject
+
+            connection.send.side_effect = connection_send
+
+            raw = Mock()
+            raw.release_conn.return_value = None
+
+            request = requests.Request()
+            response = requests.Response()
+            response.request = request
+            response.url = "http://www.example.org/"
+            response.headers = {'www-authenticate': 'negotiate token'}
+            response.status_code = 401
+            response.connection = connection
+            response._content = ""
+            response.raw = raw
+
+            auth = requests_kerberos.HTTPKerberosAuth()
+
+            r = auth.handle_response(response)
+
+            self.assertEqual(r.status_code, 401)
+            self.assertEqual(request.headers['Authorization'],
+                             'Negotiate GSSRESPONSE')
+            connection.send.assert_called_with(request)
+            raw.release_conn.assert_called_with()
+            clientInit_complete.assert_called_with("HTTP@www.example.org")
+            clientStep_continue.assert_called_with("CTX", "token")
+            clientResponse.assert_called_with("CTX")
 
     def test_generate_request_header_custom_service(self):
         with patch.multiple('kerberos',
